# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['geodatacrawler',
 'geodatacrawler.schemas.iso19139',
 'geodatacrawler.templates',
 'templates']

package_data = \
{'': ['*']}

install_requires = \
['Fiona>=1.8.21,<2.0.0',
 'GDAL==3.3.2',
 'Jinja2>=3.1.2,<4.0.0',
 'OWSLib>=0.27.2,<0.28.0',
 'PyYAML>=6.0,<7.0',
 'bibtexparser>=1.4.0,<2.0.0',
 'jinja2-time>=0.2.0,<0.3.0',
 'mappyfile>=0.9.7,<0.10.0',
 'pandas>=1.5.1,<2.0.0',
 'pygeometa==0.13.1',
 'pyproj>=3.4.0,<4.0.0',
 'pysqlite3>=0.4.6,<0.5.0',
 'pytest>=7.4.0,<8.0.0',
 'rasterio>=1.2.10,<2.0.0']

entry_points = \
{'console_scripts': ['crawl-etl = geodatacrawler.etl:etl',
                     'crawl-maps = geodatacrawler.mapfile:mapForDir',
                     'crawl-metadata = geodatacrawler.metadata:indexDir']}

setup_kwargs = {
    'name': 'geodatacrawler',
    'version': '1.1.4',
    'description': 'a crawler script to extract and author metadata of spatial datasets',
    'long_description': '# pyGeoDataCrawler\n\nThe tool crawls a data folder or tree. For each spatial file identified, it will process the file. Extract as many information as possible and store it on a sidecar metadata file. \n\nThe tool can also look for existing metadata using common conventions. For metadata imports the tool wil use [owslib](https://github.com/geopython/owslib), which supports some metadata formats. \n\nSeveral options exist for using the results of the generated index:\n\n- The resulting indexed content can be converted to iso19139 or OGCAPI-records and inserted on an instance of pycsw, geonetwork or pygeoapi, to make it searchable.\n- Automated creation of a mapserver mapfile to provide OGC services on top of the spatial files identified.\n\n## Installation\n\nThe tool requires GDAL 3.2.2 and pysqlite 0.4.6 to be installed. I recommend to use [conda](https://conda.io/) to install them.\n\n```\nconda create --name pgdc python=3.9 \nconda activate pgdc\nconda install -c conda-forge gdal==3.3.2\nconda install -c conda-forge pysqlite3==0.4.6\n```\n\nThen run:\n\n```\npip install geodatacrawler\n```\n\n## Usage \n\nThe tools are typically called from commandline or a bash script.\n\n### Index metadata\n\n```\ncrawl-metadata --mode=init --dir=/myproject/data [--out-dir=/mnt/myoutput]\n```\n\nMode explained:\n\n- `init`; creates new metadata for files which do not have it yet (not overwriting)\n- `update`; updates the metadata, merging new content on existing (not creating new)\n- `export`; exports the mcf metadata to xml and stored it in a folder (to be loaded on pycsw) or on a database (todo)\n- `import-csv`; imports a csv of metadata fiels into a series of mcf files, typically combined with a [.j2 file](geodatacrawler/templates/csv.j2) with same name, which `maps` the csv-fields to mcf-fields \n\nThe export utility will merge any yaml file to a index.yml from a parent folder. This will allow you to create minimal metadata at the detailed level, while providing more generic metadata down the tree. The index.yml is also used as a configuration for any mapfile creation (service metadata).\n\nMost parameters are configured from the commandline, check --help to get explanation.\n2 parameters can be set as an environment variable\n\n- pgdc_host is the url on which the data will be hosted in mapserver or a webdav folder.\n- pgdc_schema_path is a physical path to an override of the default iso19139 schema of pygeometa, containing jinja templates to format the exported xml\n\nSome parameters can be set in index.yml, in a robot section. Note that config is inherited from parent folders.\n\n```yaml\nmcf:\n    version 1.0\nrobot: \n  skip-subfolders: True # do not move into subfolders, typically if subfolder is a set of tiles, default: False \n  skip-files: "temp.*" # do not process files matching a regexp, default: None \n```\n\n### Create mapfile\n\nThe metadata identified can be used to create OGC services exposing the files. Currently the tool creates [mapserver mapfiles](https://www.mapserver.org/mapfile/), which are placed on a output-folder. A `index.yml` configuraton file is expected at the root of the folder to be indexed, if not, it will be created.\n\n```\ncrawl-mapfile --dir=/mnt/data [--out-dir=/mnt/mapserver/mapfiles]\n```\n\nA mapserver docker image is available which is able to expose a folder of mapfiles as mapservices, eg http://example.com/{mapfile}?request=getcapabilities&service=wms.\nIdea is that the url to the OGC service will be included in the indexed metadata.\n\n## Development\n\n### Python Poetry\n\nThe project is based on common coding conventions from the python poetry community.\n\nOn the sources, either run scripts directly:\n\n```\npoetry run crawl-mapfile --dir=/mnt/data\n```\n\nor run a shell in the poetry environment:\n\n```\npoetry shell \n```\n\nThe GDAL dependency has some installation issue on poetry, see [here](https://stackoverflow.com/a/70986804) for a workaround\n\n```\n> poetry shell\n>> sudo apt-get install gdal\n>> gdalinfo --version\nGDAL 3.3.2, released 2021/09/01\n>> pip install gdal==3.3.2\n>> exit\n```\n',
    'author': 'Paul van Genuchten',
    'author_email': 'genuchten@yahoo.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/pvgenuchten/pyGeoDataCrawler',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
